==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
export let CheckedChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CheckedChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
                CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(CheckedChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            CheckedChangedEventArgsDescriptionMetadata.b(a);
            a.aa("CheckedChangedEventArgs", () => new CheckedChangedEventArgsDescription());
            a.z("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
        }
    }
    CheckedChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
export let CheckedChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CheckedChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
                CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(CheckedChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            CheckedChangedEventArgsDescriptionMetadata.b(a);
            a.ac("CheckedChangedEventArgs", () => new CheckedChangedEventArgsDescription());
            a.ab("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
        }
    }
    CheckedChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
})();
